@@ -1,10 +1,42 @@
 <?php
 
+/**
+ * This file is part of the Froxlor project.
+ * Copyright (c) 2010 the Froxlor Team (see authors).
+ *
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License
+ * as published by the Free Software Foundation; either version 2
+ * of the License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, you can also view it online at
+ * https://files.froxlor.org/misc/COPYING.txt
+ *
+ * @copyright  the authors
+ * @author     Froxlor team <team@froxlor.org>
+ * @license    https://files.froxlor.org/misc/COPYING.txt GPLv2
+ */
+
 namespace Froxlor\Settings;
 
+use Exception;
+use Froxlor\Cron\TaskId;
 use Froxlor\Database\Database;
+use Froxlor\Database\DbManager;
 use Froxlor\FileDir;
+use Froxlor\Froxlor;
+use Froxlor\Idna\IdnaWrapper;
+use Froxlor\PhpHelper;
 use Froxlor\Settings;
+use Froxlor\System\Cronjob;
+use Froxlor\System\IPTools;
+use PDO;
 
 class Store
 {
@@ -22,6 +54,37 @@ class Store
 		return $returnvalue;
 	}
 
+	public static function storeSettingField($fieldname, $fielddata, $newfieldvalue)
+	{
+		if (is_array($fielddata) && isset($fielddata['settinggroup']) && $fielddata['settinggroup'] != '' && isset($fielddata['varname']) && $fielddata['varname'] != '') {
+			if (Settings::Set($fielddata['settinggroup'] . '.' . $fielddata['varname'], $newfieldvalue) !== false) {
+				/*
+				 * when fielddata[cronmodule] is set, this means enable/disable a cronjob
+				 */
+				if (isset($fielddata['cronmodule']) && $fielddata['cronmodule'] != '') {
+					Cronjob::toggleCronStatus($fielddata['cronmodule'], $newfieldvalue);
+				}
+
+				/*
+				 * satisfy dependencies
+				 */
+				if (isset($fielddata['dependency']) && is_array($fielddata['dependency'])) {
+					if ((int)$fielddata['dependency']['onlyif'] == (int)$newfieldvalue) {
+						self::storeSettingField($fielddata['dependency']['fieldname'], $fielddata['dependency']['fielddata'], $newfieldvalue);
+					}
+				}
+
+				return [
+					$fielddata['settinggroup'] . '.' . $fielddata['varname'] => $newfieldvalue
+				];
+			} else {
+				return false;
+			}
+		} else {
+			return false;
+		}
+	}
+
 	public static function storeSettingDefaultIp($fieldname, $fielddata, $newfieldvalue)
 	{
 		$defaultips_old = Settings::Get('system.defaultip');
@@ -35,19 +98,6 @@ class Store
 		return $returnvalue;
 	}
 
-	public static function storeSettingDefaultSslIp($fieldname, $fielddata, $newfieldvalue)
-	{
-		$defaultips_old = Settings::Get('system.defaultsslip');
-
-		$returnvalue = self::storeSettingField($fieldname, $fielddata, $newfieldvalue);
-
-		if ($returnvalue !== false && is_array($fielddata) && isset($fielddata['settinggroup']) && $fielddata['settinggroup'] == 'system' && isset($fielddata['varname']) && $fielddata['varname'] == 'defaultsslip') {
-			self::updateStdSubdomainDefaultIp($newfieldvalue, $defaultips_old);
-		}
-
-		return $returnvalue;
-	}
-
 	private static function updateStdSubdomainDefaultIp($newfieldvalue, $defaultips_old)
 	{
 		// update standard-subdomain of customer if exists
@@ -56,9 +106,9 @@ class Store
 		");
 		Database::pexecute($customerstddomains_result_stmt);
 
-		$ids = array();
-		while ($customerstddomains_row = $customerstddomains_result_stmt->fetch(\PDO::FETCH_ASSOC)) {
-			$ids[] = (int) $customerstddomains_row['standardsubdomain'];
+		$ids = [];
+		while ($customerstddomains_row = $customerstddomains_result_stmt->fetch(PDO::FETCH_ASSOC)) {
+			$ids[] = (int)$customerstddomains_row['standardsubdomain'];
 		}
 
 		if (count($ids) > 0) {
@@ -89,16 +139,29 @@ class Store
 
 				foreach ($ids as $id) {
 					foreach ($defaultips_new as $defaultip_new) {
-						Database::pexecute($ins_stmt, array(
+						Database::pexecute($ins_stmt, [
 							'domainid' => $id,
 							'ipandportid' => $defaultip_new
-						));
+						]);
 					}
 				}
 			}
 		}
 	}
 
+	public static function storeSettingDefaultSslIp($fieldname, $fielddata, $newfieldvalue)
+	{
+		$defaultips_old = Settings::Get('system.defaultsslip');
+
+		$returnvalue = self::storeSettingField($fieldname, $fielddata, $newfieldvalue);
+
+		if ($returnvalue !== false && is_array($fielddata) && isset($fielddata['settinggroup']) && $fielddata['settinggroup'] == 'system' && isset($fielddata['varname']) && $fielddata['varname'] == 'defaultsslip') {
+			self::updateStdSubdomainDefaultIp($newfieldvalue, $defaultips_old);
+		}
+
+		return $returnvalue;
+	}
+
 	/**
 	 * updates the setting for the default panel-theme
 	 * and also the user themes (customers and admins) if
@@ -122,61 +185,30 @@ class Store
 				$upd_stmt = Database::prepare("
 					UPDATE `" . TABLE_PANEL_CUSTOMERS . "` SET `theme` = :theme
 				");
-				Database::pexecute($upd_stmt, array(
+				Database::pexecute($upd_stmt, [
 					'theme' => $newfieldvalue
-				));
+				]);
 			}
 			if (Settings::Get('panel.allow_theme_change_admin') == '0') {
 				$upd_stmt = Database::prepare("
 					UPDATE `" . TABLE_PANEL_ADMINS . "` SET `theme` = :theme
 				");
-				Database::pexecute($upd_stmt, array(
+				Database::pexecute($upd_stmt, [
 					'theme' => $newfieldvalue
-				));
+				]);
 			}
 		}
 
 		return $returnvalue;
 	}
 
-	public static function storeSettingField($fieldname, $fielddata, $newfieldvalue)
-	{
-		if (is_array($fielddata) && isset($fielddata['settinggroup']) && $fielddata['settinggroup'] != '' && isset($fielddata['varname']) && $fielddata['varname'] != '') {
-			if (Settings::Set($fielddata['settinggroup'] . '.' . $fielddata['varname'], $newfieldvalue) !== false) {
-				/*
-				 * when fielddata[cronmodule] is set, this means enable/disable a cronjob
-				 */
-				if (isset($fielddata['cronmodule']) && $fielddata['cronmodule'] != '') {
-					\Froxlor\System\Cronjob::toggleCronStatus($fielddata['cronmodule'], $newfieldvalue);
-				}
-
-				/*
-				 * satisfy dependencies
-				 */
-				if (isset($fielddata['dependency']) && is_array($fielddata['dependency'])) {
-					if ((int) $fielddata['dependency']['onlyif'] == (int) $newfieldvalue) {
-						self::storeSettingField($fielddata['dependency']['fieldname'], $fielddata['dependency']['fielddata'], $newfieldvalue);
-					}
-				}
-
-				return array(
-					$fielddata['settinggroup'] . '.' . $fielddata['varname'] => $newfieldvalue
-				);
-			} else {
-				return false;
-			}
-		} else {
-			return false;
-		}
-	}
-
 	public static function storeSettingFieldInsertBindTask($fieldname, $fielddata, $newfieldvalue)
 	{
 		// first save the setting itself
 		$returnvalue = self::storeSettingField($fieldname, $fielddata, $newfieldvalue);
 
 		if ($returnvalue !== false) {
-			\Froxlor\System\Cronjob::inserttask(\Froxlor\Cron\TaskId::REBUILD_DNS);
+			Cronjob::inserttask(TaskId::REBUILD_DNS);
 		}
 		return $returnvalue;
 	}
@@ -186,7 +218,7 @@ class Store
 		$returnvalue = self::storeSettingField($fieldname, $fielddata, $newfieldvalue);
 
 		if ($returnvalue !== false && is_array($fielddata) && isset($fielddata['settinggroup']) && $fielddata['settinggroup'] == 'system' && isset($fielddata['varname']) && ($fielddata['varname'] == 'hostname' || $fielddata['varname'] == 'stdsubdomain')) {
-			$idna_convert = new \Froxlor\Idna\IdnaWrapper();
+			$idna_convert = new IdnaWrapper();
 			$newfieldvalue = $idna_convert->encode($newfieldvalue);
 
 			if (($fielddata['varname'] == 'hostname' && Settings::Get('system.stdsubdomain') == '') || $fielddata['varname'] == 'stdsubdomain') {
@@ -213,10 +245,10 @@ class Store
 				");
 				Database::pexecute($customerstddomains_result_stmt);
 
-				$ids = array();
+				$ids = [];
 
-				while ($customerstddomains_row = $customerstddomains_result_stmt->fetch(\PDO::FETCH_ASSOC)) {
-					$ids[] = (int) $customerstddomains_row['standardsubdomain'];
+				while ($customerstddomains_row = $customerstddomains_result_stmt->fetch(PDO::FETCH_ASSOC)) {
+					$ids[] = (int)$customerstddomains_row['standardsubdomain'];
 				}
 
 				if (count($ids) > 0) {
@@ -225,10 +257,10 @@ class Store
 						`domain` = REPLACE(`domain`, :host, :newval)
 						WHERE `id` IN ('" . implode(', ', $ids) . "')
 					");
-					Database::pexecute($upd_stmt, array(
+					Database::pexecute($upd_stmt, [
 						'host' => $oldhost,
 						'newval' => $newhost
-					));
+					]);
 				}
 			}
 		}
@@ -243,8 +275,8 @@ class Store
 		if ($returnvalue !== false && is_array($fielddata) && isset($fielddata['settinggroup']) && $fielddata['settinggroup'] == 'system' && isset($fielddata['varname']) && $fielddata['varname'] == 'ipaddress') {
 			$mysql_access_host_array = array_map('trim', explode(',', Settings::Get('system.mysql_access_host')));
 			$mysql_access_host_array[] = $newfieldvalue;
-			$mysql_access_host_array = array_unique(\Froxlor\PhpHelper::arrayTrim($mysql_access_host_array));
-			\Froxlor\Database\DbManager::correctMysqlUsers($mysql_access_host_array);
+			$mysql_access_host_array = array_unique(PhpHelper::arrayTrim($mysql_access_host_array));
+			DbManager::correctMysqlUsers($mysql_access_host_array);
 			$mysql_access_host = implode(',', $mysql_access_host_array);
 			Settings::Set('system.mysql_access_host', $mysql_access_host);
 		}
@@ -267,7 +299,7 @@ class Store
 				if (count($ip_cidr) === 2) {
 					$ip = $ip_cidr[0];
 					if (strlen($ip_cidr[1]) <= 2) {
-						$ip_cidr[1] = \Froxlor\Validate\Validate::cidr2NetmaskAddr($org_ip);
+						$ip_cidr[1] = IPTools::cidr2NetmaskAddr($org_ip);
 					}
 					$newfieldvalue[] = $ip . '/' . $ip_cidr[1];
 				} else {
@@ -290,14 +322,14 @@ class Store
 			}
 
 			// be aware that ipv6 addresses are enclosed in [ ] when passed here
-			$mysql_access_host_array = array_map(array(
+			$mysql_access_host_array = array_map([
 				'\\Froxlor\\Settings\\Store',
 				'cleanMySQLAccessHost'
-			), $mysql_access_host_array);
+			], $mysql_access_host_array);
 
-			$mysql_access_host_array = array_unique(\Froxlor\PhpHelper::arrayTrim($mysql_access_host_array));
+			$mysql_access_host_array = array_unique(PhpHelper::arrayTrim($mysql_access_host_array));
 			$newfieldvalue = implode(',', $mysql_access_host_array);
-			\Froxlor\Database\DbManager::correctMysqlUsers($mysql_access_host_array);
+			DbManager::correctMysqlUsers($mysql_access_host_array);
 			$mysql_access_host = implode(',', $mysql_access_host_array);
 			Settings::Set('system.mysql_access_host', $mysql_access_host);
 		}
@@ -305,14 +337,6 @@ class Store
 		return $returnvalue;
 	}
 
-	private static function cleanMySQLAccessHost($value)
-	{
-		if (substr($value, 0, 1) == '[' && substr($value, -1) == ']') {
-			return substr($value, 1, -1);
-		}
-		return $value;
-	}
-
 	public static function storeSettingResetCatchall($fieldname, $fielddata, $newfieldvalue)
 	{
 		$returnvalue = self::storeSettingField($fieldname, $fielddata, $newfieldvalue);
@@ -333,7 +357,6 @@ class Store
 	public static function storeSettingWebserverFcgidFpmUser($fieldname, $fielddata, $newfieldvalue)
 	{
 		if (is_array($fielddata) && isset($fielddata['settinggroup']) && isset($fielddata['varname'])) {
-
 			$update_user = null;
 
 			// webserver
@@ -359,10 +382,10 @@ class Store
 				 */
 				if ($update_user != null && $newfieldvalue != $update_user) {
 					$upd_stmt = Database::prepare("UPDATE `" . TABLE_FTP_GROUPS . "` SET `members` = REPLACE(`members`, :olduser, :newuser)");
-					Database::pexecute($upd_stmt, array(
+					Database::pexecute($upd_stmt, [
 						'olduser' => $update_user,
 						'newuser' => $newfieldvalue
-					));
+					]);
 				}
 			}
 		}
@@ -374,20 +397,20 @@ class Store
 	{
 		if (isset($fielddata['settinggroup'], $fielddata['varname']) && is_array($fielddata) && $fielddata['settinggroup'] !== '' && $fielddata['varname'] !== '') {
 			$save_to = null;
-			$path = \Froxlor\Froxlor::getInstallDir() . '/img/';
-			$path = \Froxlor\FileDir::makeCorrectDir($path);
+			$path = Froxlor::getInstallDir() . '/img/';
+			$path = FileDir::makeCorrectDir($path);
 
 			// New file?
 			if (isset($_FILES[$fieldname]) && $_FILES[$fieldname]['tmp_name']) {
 				// Make sure upload directory exists
 				if (!is_dir($path) && !mkdir($path, 0775)) {
-					throw new \Exception("img directory does not exist and cannot be created");
+					throw new Exception("img directory does not exist and cannot be created");
 				}
 
 				// Make sure we can write to the upload directory
 				if (!is_writable($path)) {
 					if (!chmod($path, 0775)) {
-						throw new \Exception("Cannot write to img directory");
+						throw new Exception("Cannot write to img directory");
 					}
 				}
 
@@ -422,7 +445,7 @@ class Store
 
 				// Move file
 				if (!move_uploaded_file($_FILES[$fieldname]['tmp_name'], $path . $fielddata['image_name'] . '.' . $file_extension)) {
-					throw new \Exception("Unable to save image to img folder");
+					throw new Exception("Unable to save image to img folder");
 				}
 
 				$save_to = 'img/' . $fielddata['image_name'] . '.' . $file_extension . '?v=' . time();
@@ -430,26 +453,61 @@ class Store
 
 			// Delete file?
 			if ($fielddata['value'] !== "" && array_key_exists($fieldname . '_delete', $_POST) && $_POST[$fieldname . '_delete']) {
-				@unlink(\Froxlor\Froxlor::getInstallDir() . '/' . explode('?', $fielddata['value'], 2)[0]);
+				@unlink(Froxlor::getInstallDir() . '/' . explode('?', $fielddata['value'], 2)[0]);
 				$save_to = '';
 			}
 
 			// Nothing changed
 			if ($save_to === null) {
-				return array(
+				return [
 					$fielddata['settinggroup'] . '.' . $fielddata['varname'] => $fielddata['value']
-				);
+				];
 			}
 
 			if (Settings::Set($fielddata['settinggroup'] . '.' . $fielddata['varname'], $save_to) === false) {
 				return false;
 			}
 
-			return array(
+			return [
 				$fielddata['settinggroup'] . '.' . $fielddata['varname'] => $save_to
-			);
+			];
 		}
 
 		return false;
 	}
+
+	private static function cleanMySQLAccessHost($value)
+	{
+		if (substr($value, 0, 1) == '[' && substr($value, -1) == ']') {
+			return substr($value, 1, -1);
+		}
+		return $value;
+	}
+
+	public static function storeSettingUpdateTrafficTool($fieldname, $fielddata, $newfieldvalue)
+	{
+		$returnvalue = self::storeSettingField($fieldname, $fielddata, $newfieldvalue);
+
+		if ($returnvalue !== false && is_array($fielddata) && isset($fielddata['settinggroup']) && $fielddata['settinggroup'] == 'system' && isset($fielddata['varname']) && $fielddata['varname'] == 'traffictool' && $newfieldvalue != $fielddata['value']) {
+			$oldpath = '/' . $fielddata['value'] . '/';
+			$newpath = '/' . $newfieldvalue . '/';
+			$sel_stmt = Database::prepare("SELECT * FROM `" . TABLE_PANEL_HTPASSWDS . "` WHERE `path` LIKE :oldpath");
+			$upd_stmt = Database::prepare("
+				UPDATE `" . TABLE_PANEL_HTPASSWDS . "` SET `path` = :newpath WHERE `id` = :id
+			");
+			Database::pexecute($sel_stmt, [
+				'oldpath' => '%' . $oldpath
+			]);
+			while ($entry = $sel_stmt->fetch(\PDO::FETCH_ASSOC)) {
+				$full_path = str_replace($oldpath, $newpath, $entry['path']);
+				$eid = (int)$entry['id'];
+				Database::pexecute($upd_stmt, [
+					'newpath' => $full_path,
+					'id' => $eid
+				]);
+			}
+		}
+
+		return $returnvalue;
+	}
 }
